@@ -22,12 +22,15 @@ from sqlalchemy_utils import types
 from wtforms_components import (
     ColorField,
     DateField,
+    DateIntervalField,
     DateTimeField,
+    DateTimeIntervalField,
     DateTimeLocalField,
     DecimalField,
+    DecimalIntervalField,
     EmailField,
     IntegerField,
-    NumberRangeField,
+    IntIntervalField,
     PhoneNumberField,
     SelectField,
     StringField,
@@ -87,8 +90,11 @@ class FormGenerator(object):
         (types.ArrowType, DateTimeField),
         (types.ChoiceType, SelectField),
         (types.ColorType, ColorField),
+        (types.DateRangeType, DateIntervalField),
+        (types.DateTimeRangeType, DateTimeIntervalField),
         (types.EmailType, EmailField),
-        (types.NumberRangeType, NumberRangeField),
+        (types.IntRangeType, IntIntervalField),
+        (types.NumericRangeType, DecimalIntervalField),
         (types.PasswordType, PasswordField),
         (types.PhoneNumberType, PhoneNumberField),
         (types.ScalarListType, StringField),
